==> viking_1.3.orig.tar.gz: viking-1.3/src/menu.xml.h <==
#ifndef __VIKING_MENU_XML_H
#define __VIKING_MENU_XML_H

static const char *menu_xml =
	"<ui>"
	"  <menubar name='MainMenu'>"
	"    <menu action='File'>"
	"      <menuitem action='New'/>"
	"      <menuitem action='Open'/>"
	"      <menuitem action='OpenRecentFile'/>"
	"      <menuitem action='Append'/>"
	"      <menuitem action='Save'/>"
	"      <menuitem action='SaveAs'/>"
	"      <separator/>"
	"      <menu action='Acquire'>"
	"        <menuitem action='AcquireGPS'/>"
	"        <menuitem action='AcquireGPSBabel'/>"
	"        <menuitem action='AcquireGoogle'/>"
#ifdef VIK_CONFIG_OPENSTREETMAP
	"        <menuitem action='AcquireOSM'/>"
#endif
#ifdef VIK_CONFIG_GEOCACHES
	"        <menuitem action='AcquireGC'/>"
#endif
#ifdef VIK_CONFIG_GEOTAG
	"        <menuitem action='AcquireGeotag'/>"
#endif
	"      </menu>"
	"      <separator/>"
	"      <menuitem action='GenImg'/>"
	"      <menuitem action='GenImgDir'/>"
#if GTK_CHECK_VERSION(2,10,0)
	"      <menuitem action='Print'/>"
#endif
	"      <separator/>"
	"      <menuitem action='SaveExit'/>"
	"      <menuitem action='Exit'/>"
	"    </menu>"
	"    <menu action='Edit'>"
	"      <menuitem action='Cut'/>"
	"      <menuitem action='Copy'/>"
	"      <menuitem action='Paste'/>"
	"      <menuitem action='Delete'/>"
	"      <menuitem action='DeleteAll'/>"
	"      <separator/>"
	"      <menuitem action='MapCacheFlush'/>"
	"      <menuitem action='SetDefaultLocation'/>"
	"      <menuitem action='Preferences'/>"
	"    </menu>"
	"    <menu action='View'>"
	"      <menuitem action='ModeUTM'/>"
#ifdef VIK_CONFIG_EXPEDIA
	"      <menuitem action='ModeExpedia'/>"
#endif
	"      <menuitem action='ModeLatLon'/>"
	"      <menuitem action='ModeMercator'/>"
	"      <separator/>"
	"      <menuitem action='GotoDefaultLocation'/>"
	"      <menuitem action='GotoSearch'/>"
	"      <menuitem action='GotoLL'/>"
	"      <menuitem action='GotoUTM'/>"
	"      <separator/>"
	"      <menuitem action='SetBGColor'/>"
	"      <menuitem action='SetHLColor'/>"
	"      <menuitem action='FullScreen'/>"
	"      <menu action='SetShow'>"
	"          <menuitem action='ShowScale'/>"
	"          <menuitem action='ShowCenterMark'/>"
	"          <menuitem action='ShowHighlight'/>"
	"          <menuitem action='ViewSidePanel'/>"
	"          <menuitem action='ViewStatusBar'/>"
	"          <menuitem action='ViewToolbar'/>"
	"          <menuitem action='ViewMainMenu'/>"
	"      </menu>"
	"      <separator/>"
	"      <menuitem action='ZoomIn'/>"
	"      <menuitem action='ZoomOut'/>"
	"      <menuitem action='ZoomTo'/>"
	"      <menu action='SetZoom'>"
	"        <menuitem action='Zoom0.25'/>"
	"        <menuitem action='Zoom0.5'/>"
	"        <menuitem action='Zoom1'/>"
	"        <menuitem action='Zoom2'/>"
	"        <menuitem action='Zoom4'/>"
	"        <menuitem action='Zoom8'/>"
	"        <menuitem action='Zoom16'/>"
	"        <menuitem action='Zoom32'/>"
	"        <menuitem action='Zoom64'/>"
	"        <menuitem action='Zoom128'/>"
	"        <menuitem action='Zoom256'/>"
	"        <menuitem action='Zoom512'/>"
	"        <menuitem action='Zoom1024'/>"
	"        <menuitem action='Zoom2048'/>"
	"        <menuitem action='Zoom4096'/>"
	"        <menuitem action='Zoom8192'/>"
	"        <menuitem action='Zoom16384'/>"
	"        <menuitem action='Zoom32768'/>"
	"      </menu>"
        "      <menu action='SetPan'>"
        "          <menuitem action='PanNorth'/>"
        "          <menuitem action='PanEast'/>"
        "          <menuitem action='PanWest'/>"
        "          <menuitem action='PanSouth'/>"
	"      </menu>"
	"      <separator/>"
	"      <menuitem action='BGJobs'/>"
	"    </menu>"
	"    <menu action='Layers'>"
	"      <menuitem action='Properties'/>"
	"      <separator/>"
	"    </menu>"
	"    <menu action='Tools'>"
	"      <menu action='Exttools'/>"
	"      <menuitem action='Pan'/>"
	"      <menuitem action='Zoom'/>"
	"      <menuitem action='Ruler'/>"
	"      <menuitem action='Select'/>"
	"    </menu>"
	"    <menu action='Help'>"
	"      <menuitem action='HelpEntry'/>"
	"      <menuitem action='About'/>"
	"    </menu>"
	"  </menubar>"
	"  <toolbar name='MainToolbar'>"
	"    <placeholder name='FileToolItems'>"
	"      <toolitem name='New' action='New'/>"
	"      <toolitem name='Open' action='Open'/>"
	"      <toolitem name='Save' action='Save'/>"
#if GTK_CHECK_VERSION(2,10,0)
	"      <toolitem name='Print' action='Print'/>"
#endif
	"      <toolitem name='Exit' action='Exit'/>"
	"      <separator/>"
	"    </placeholder>"
	"    <placeholder name='UIToolItems'>"
	"      <toolitem action='FullScreen'/>"
	"      <toolitem action='ViewSidePanel'/>"
	"      <separator/>"
	"    </placeholder>"
	"    <placeholder name='ViewToolItems'>"
	"      <toolitem action='GotoDefaultLocation'/>"
	"      <toolitem action='GotoSearch'/>"
	"      <separator/>"
	"    </placeholder>"
	"    <placeholder name='ToolItems'>"
	"    <toolitem action='Pan'/>"
	"    <toolitem action='Zoom'/>"
	"    <toolitem action='Ruler'/>"
	"    <toolitem action='Select'/>"
	"    </placeholder>"
	"  </toolbar>"
	"</ui>"
;

#endif

==> viking_1.4.2.orig.tar.gz: viking-1.4.2/src/menu.xml.h <==
#ifndef __VIKING_MENU_XML_H
#define __VIKING_MENU_XML_H

static const char *menu_xml =
	"<ui>"
	"  <menubar name='MainMenu'>"
	"    <menu action='File'>"
	"      <menuitem action='New'/>"
	"      <menuitem action='Open'/>"
	"      <menuitem action='OpenRecentFile'/>"
	"      <menuitem action='Append'/>"
	"      <menuitem action='Save'/>"
	"      <menuitem action='SaveAs'/>"
	"      <separator/>"
	"      <menu action='Acquire'>"
	"        <menuitem action='AcquireGPS'/>"
	"        <menuitem action='AcquireGPSBabel'/>"
#ifdef VIK_CONFIG_GOOGLE
	"        <menuitem action='AcquireGoogle'/>"
#endif
#ifdef VIK_CONFIG_OPENSTREETMAP
	"        <menuitem action='AcquireOSM'/>"
	"        <menuitem action='AcquireMyOSM'/>"
#endif
#ifdef VIK_CONFIG_GEOCACHES
	"        <menuitem action='AcquireGC'/>"
#endif
#ifdef VIK_CONFIG_GEOTAG
	"        <menuitem action='AcquireGeotag'/>"
#endif
#ifdef VIK_CONFIG_GEONAMES
	"        <menuitem action='AcquireWikipedia'/>"
#endif
	"      </menu>"
	"      <separator/>"
	"      <menuitem action='GenImg'/>"
	"      <menuitem action='GenImgDir'/>"
#if GTK_CHECK_VERSION(2,10,0)
	"      <menuitem action='Print'/>"
#endif
	"      <separator/>"
	"      <menuitem action='SaveExit'/>"
	"      <menuitem action='Exit'/>"
	"    </menu>"
	"    <menu action='Edit'>"
	"      <menuitem action='Cut'/>"
	"      <menuitem action='Copy'/>"
	"      <menuitem action='Paste'/>"
	"      <menuitem action='Delete'/>"
	"      <menuitem action='DeleteAll'/>"
	"      <separator/>"
	"      <menuitem action='MapCacheFlush'/>"
	"      <menuitem action='SetDefaultLocation'/>"
	"      <menuitem action='Preferences'/>"
	"    </menu>"
	"    <menu action='View'>"
	"      <menuitem action='ModeUTM'/>"
#ifdef VIK_CONFIG_EXPEDIA
	"      <menuitem action='ModeExpedia'/>"
#endif
	"      <menuitem action='ModeLatLon'/>"
	"      <menuitem action='ModeMercator'/>"
	"      <separator/>"
	"      <menuitem action='GotoDefaultLocation'/>"
	"      <menuitem action='GotoSearch'/>"
	"      <menuitem action='GotoLL'/>"
	"      <menuitem action='GotoUTM'/>"
	"      <separator/>"
	"      <menuitem action='Refresh'/>"
	"      <separator/>"
	"      <menuitem action='SetBGColor'/>"
	"      <menuitem action='SetHLColor'/>"
	"      <menuitem action='FullScreen'/>"
	"      <menu action='SetShow'>"
	"          <menuitem action='ShowScale'/>"
	"          <menuitem action='ShowCenterMark'/>"
	"          <menuitem action='ShowHighlight'/>"
	"          <menuitem action='ViewSidePanel'/>"
	"          <menuitem action='ViewStatusBar'/>"
	"          <menuitem action='ViewToolbar'/>"
	"          <menuitem action='ViewMainMenu'/>"
	"      </menu>"
	"      <separator/>"
	"      <menuitem action='ZoomIn'/>"
	"      <menuitem action='ZoomOut'/>"
	"      <menuitem action='ZoomTo'/>"
	"      <menu action='SetZoom'>"
	"        <placeholder name='ZoomLevels'/>"
	"      </menu>"
        "      <menu action='SetPan'>"
        "          <menuitem action='PanNorth'/>"
        "          <menuitem action='PanEast'/>"
        "          <menuitem action='PanWest'/>"
        "          <menuitem action='PanSouth'/>"
	"      </menu>"
	"      <separator/>"
	"      <menuitem action='BGJobs'/>"
	"    </menu>"
	"    <menu action='Layers'>"
	"      <menuitem action='Properties'/>"
	"      <separator/>"
	"    </menu>"
	"    <menu action='Tools'>"
	"      <menu action='Exttools'/>"
	"      <menuitem action='Pan'/>"
	"      <menuitem action='Zoom'/>"
	"      <menuitem action='Ruler'/>"
	"      <menuitem action='Select'/>"
	"    </menu>"
	"    <menu action='Help'>"
	"      <menuitem action='HelpEntry'/>"
	"      <menuitem action='About'/>"
	"    </menu>"
	"  </menubar>"
	"  <toolbar name='MainToolbar'>"
	"    <placeholder name='FileToolItems'>"
	"      <toolitem name='New' action='New'/>"
	"      <toolitem name='Open' action='Open'/>"
	"      <toolitem name='Save' action='Save'/>"
#if GTK_CHECK_VERSION(2,10,0)
	"      <toolitem name='Print' action='Print'/>"
#endif
	"      <toolitem name='Exit' action='Exit'/>"
	"      <separator/>"
	"    </placeholder>"
	"    <placeholder name='UIToolItems'>"
	"      <toolitem action='FullScreen'/>"
	"      <toolitem action='ViewSidePanel'/>"
	"      <separator/>"
	"    </placeholder>"
	"    <placeholder name='ViewToolItems'>"
	"      <toolitem action='GotoDefaultLocation'/>"
	"      <toolitem action='GotoSearch'/>"
	"      <separator/>"
	"    </placeholder>"
	"    <placeholder name='ToolItems'>"
	"    <toolitem action='Pan'/>"
	"    <toolitem action='Zoom'/>"
	"    <toolitem action='Ruler'/>"
	"    <toolitem action='Select'/>"
	"    </placeholder>"
	"  </toolbar>"
	"</ui>"
;

#endif
